==> qt-creator-opensource-src-4.4.1.tar.gz: qt-creator-opensource-src-4.4.1/src/plugins/vcsbase/basevcseditorfactory.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "vcsbase_global.h"

#include <texteditor/texteditor.h>

#include <functional>

namespace VcsBase {
class VcsBaseEditor;
class VcsBaseEditorParameters;

class VCSBASE_EXPORT VcsEditorFactory : public TextEditor::TextEditorFactory
{
    Q_OBJECT

public:
    VcsEditorFactory(const VcsBaseEditorParameters *parameters,
                     const EditorWidgetCreator editorWidgetCreator,
                     std::function<void(const QString &, const QString &)> describeFunc);

    static VcsBaseEditor *createEditorById(const char *id);
};

} // namespace VcsBase

==> qt-creator-opensource-src-8.0.0-rc1.tar.gz: qt-creator-opensource-src-8.0.0-rc1/src/plugins/vcsbase/basevcseditorfactory.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "vcsbase_global.h"

#include <texteditor/texteditor.h>

#include <functional>

namespace VcsBase {
class VcsBaseEditor;
class VcsBaseEditorParameters;

class VCSBASE_EXPORT VcsEditorFactory : public TextEditor::TextEditorFactory
{
public:
    VcsEditorFactory(const VcsBaseEditorParameters *parameters,
                     const EditorWidgetCreator editorWidgetCreator,
                     std::function<void(const Utils::FilePath &, const QString &)> describeFunc);

    ~VcsEditorFactory();
};

} // namespace VcsBase
